package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TEmergentPeople;
import com.ruoyi.system.service.ITEmergentPeopleService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 紧急联系人Controller
 * 
 * @author ruoyi
 * @date 2023-08-25
 */
@RestController
@RequestMapping("/system/people")
public class TEmergentPeopleController extends BaseController
{
    @Autowired
    private ITEmergentPeopleService tEmergentPeopleService;

    /**
     * 查询紧急联系人列表
     */
    @PreAuthorize("@ss.hasPermi('system:people:list')")
    @GetMapping("/list")
    public TableDataInfo list(TEmergentPeople tEmergentPeople)
    {
        startPage();
        List<TEmergentPeople> list = tEmergentPeopleService.selectTEmergentPeopleList(tEmergentPeople);
        return getDataTable(list);
    }

    /**
     * 导出紧急联系人列表
     */
    @PreAuthorize("@ss.hasPermi('system:people:export')")
    @Log(title = "紧急联系人", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TEmergentPeople tEmergentPeople)
    {
        List<TEmergentPeople> list = tEmergentPeopleService.selectTEmergentPeopleList(tEmergentPeople);
        ExcelUtil<TEmergentPeople> util = new ExcelUtil<TEmergentPeople>(TEmergentPeople.class);
        util.exportExcel(response, list, "紧急联系人数据");
    }

    /**
     * 获取紧急联系人详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:people:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(tEmergentPeopleService.selectTEmergentPeopleById(id));
    }

    /**
     * 新增紧急联系人
     */
    @PreAuthorize("@ss.hasPermi('system:people:add')")
    @Log(title = "紧急联系人", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TEmergentPeople tEmergentPeople)
    {
        return toAjax(tEmergentPeopleService.insertTEmergentPeople(tEmergentPeople));
    }

    /**
     * 修改紧急联系人
     */
    @PreAuthorize("@ss.hasPermi('system:people:edit')")
    @Log(title = "紧急联系人", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TEmergentPeople tEmergentPeople)
    {
        return toAjax(tEmergentPeopleService.updateTEmergentPeople(tEmergentPeople));
    }

    /**
     * 删除紧急联系人
     */
    @PreAuthorize("@ss.hasPermi('system:people:remove')")
    @Log(title = "紧急联系人", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(tEmergentPeopleService.deleteTEmergentPeopleByIds(ids));
    }
}
